//
//  CardMatchingGame.m
//  FlipCard
//
//  Created by Sameh Fakhouri on 9/10/15.
//  Copyright (c) 2015 Lehman College. All rights reserved.
//

#import "CardMatchingGame.h"

@interface CardMatchingGame()
@property (nonatomic, readwrite) NSUInteger score;
@property (nonatomic, strong) NSMutableArray *cards;
@end



@implementation CardMatchingGame


static const int MISMATCH_PENALTY = 2;
static const int MATCH_BONUS = 4;
static const int COST_TO_CHOOSE = 1;

- (NSMutableArray *)cards {
    if (!_cards) {
        _cards = [[NSMutableArray alloc] init];
    }
    return _cards;
}


- (Card *) cardAtIndex:(NSUInteger)index {
    if (index < [self.cards count]) {
        return self.cards[index];
    } else {
        return nil;
    }
}


- (void) chooseCardAtIndex:(NSUInteger)index {
    Card *card = self.cards[index];
    
    if(![card isMatched]) {
        if ([card isChosen]) {
            card.chosen = NO;
        } else {
            for (Card *otherCard in self.cards) {
                if (otherCard.isChosen && !otherCard.isMatched) {
                    int matchScore = [card match:@[otherCard]];
                    
                    if(matchScore) {
                        self.score += matchScore * MATCH_BONUS;
                        otherCard.matched = YES;
                        card.matched = YES;
                    } else {
                        self.score -= MISMATCH_PENALTY;
                        otherCard.chosen = NO;
                    }
                    break;
                }
            }
            self.score -= COST_TO_CHOOSE;
            card.chosen = YES;
        }
        
        
        
        
        
        
        
        
        
    }
    
    
    
    
    
    
}



- (instancetype)initWithCardCount:(NSUInteger)count usingDeck:(Deck *)deck {
   
    self = [super init]; // designated superclass initiliizer
    
    if (self) {
        for ( int i = 0 ; i < count ; i++ ) {
            Card *card = [deck drawRandomCard];
            if (card) {
                [self.cards addObject:card];
            } else {
                self = nil;
                break;
            }
        }
     }
    
    return self;
}






















@end
